// 云函数入口文件
const cloud = require('wx-server-sdk')

cloud.init({
  env: cloud.DYNAMIC_CURRENT_ENV
})
const db = cloud.database();
// 云函数入口函数
exports.main = async (event, context) => {

  switch (event.action) {
    case 'add': {
      return addFood(event)
    }
    case 'del': {
      return delFood(event)
    }
    case 'edit': {
      return editFood(event)
    }
    case 'find': {
      return findFood(event)
    }
    case 'findListByCategoryType': {
      return findListByCategoryType(event)
    }
    case 'findAllList':{
      return findAllList(event)
    }
    default: {
      return
    }
  }
}
/**
 * 添加一条食品信息
 */
async function addFood(event){
  const wxContext = cloud.getWXContext()
  const userIds = await db.collection('user').where({
    _openid: wxContext.OPENID
  }).field({
    _id:true
  }).get()
  console.log(userIds)

  try{
    const result = await db.collection('food').add({
      data: {
        food_name: event.name,
        food_price: event.price,
        food_desc: event.desc,
        food_order: event.order,
        category_type: event.category_type,
        food_imgs: event.img,
        create_user: userIds.data[0]._id,
        create_time: new Date()
      }
    })
    if (result.errMsg == 'collection.add:ok') {
      return {
        code: 1,
        data: null,
        msg: '添加成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '添加失败'
    }
  }catch(e){
    console.error(e)
    return {
      code: 0,
      data: null,
      msg: '添加失败'
    }
  }
}
/**
 * 根据id删除食品信息
 */
async function delFood(event) {
  try {
    const result = await db.collection('food').doc(event._id).remove();
    if (result.errMsg == 'document.remove:ok'){
       return {
         code: 1,
         data: null,
         msg: '删除成功'
       }
    }
    return {
      code: 0,
      data: null,
      msg: '删除失败'
    }
  }catch(e){
    console.error(e);
    return {
      code: 0,
      data: null,
      msg: '删除失败'
    }
  }
}
/**根据id更新食品信息
 * 
 */
async function editFood(event) {
  try {
    const result = await db.collection('food').doc(event._id).update({
      data:{
        food_name: event.name,
        foodPrice: event.price,
        food_desc: event.desc,
        food_order: event.order,
        category_type: event.category_type,
        food_imgs: event.img,
        update_time: new Date()
      }
    });
    if (result.errMsg == 'document.update:ok') {
      return {
        code: 1,
        data: null,
        msg: '更新成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '更新失败'
    }
  } catch (e) {
    console.error(e);
    return {
      code: 0,
      data: null,
      msg: '更新失败'
    }
  }
}
/**
 * 根据id查询当前食品信息
 */
async function findFood(event) {
  try {
    const result = await db.collection('food').doc(event._id).get();
    console.log(result)
    if (result.errMsg == 'document.get:ok') {
      return {
        code: 1,
        data: result.data,
        msg: '查询成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '查询失败'
    }
  } catch (e) {
    console.error(e);
    return {
      code: 0,
      data: null,
      msg: '查询失败'
    }
  }
}
/**
 * 根据分类编号查询食品信息
 */
async function findListByCategoryType(event){
  try{
    const result = await db.collection('food').where({
      category_type: event.category_type
    }).get();
    if(result.errMsg == 'collection.get:ok'){
      return {
        code:1,
        data: result.data,
        msg:'查询成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '查询失败'
    }
  }catch(e){
    return {
      code: 0,
      data: null,
      msg: '查询失败'
    }
  }
}
/**
 * 查询所有食品
 */
async function findAllList(event) {
  try {
    const result = await db.collection('food').get();
    if (result.errMsg == 'collection.get:ok') {
      return {
        code: 1,
        data: result.data,
        msg: '查询成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '查询失败'
    }
  } catch (e) {
    return {
      code: 0,
      data: null,
      msg: '查询失败'
    }
  }
}